<?php
$TRANSLATIONS = array(
"This file is too big to be opened. Please download the file instead." => "Este arquivo é muito grande para ser aberto. Por favor baixe o arquivo ao invés de abri-lo.",
"Cannot read the file." => "Não é possível ler o arquivo.",
"Invalid file path supplied." => "O caminho do arquivo que foi fornecido é inválido.",
"The file is locked." => "O arquivo está bloqueado.",
"An internal server error occurred." => "Ocorreu um erro interno do servidor.",
"Cannot save file as it has been modified since opening" => "Não é possível salvar arquivo como ele foi modificado desde a abertura",
"Insufficient permissions" => "Permissões insuficientes",
"File path not supplied" => "Caminho do arquivo não fornecido",
"File mtime not supplied" => "Data de mudança mtime do arquivo não especificada",
"saving..." => "salvando...",
"saved!" => "salvo!",
"failed!" => "falhou!",
"Saved" => "Salvo",
"There was a problem saving your changes. Click to resume editing." => "Houve um problema ao salvar suas alterações. Clica para retomar a edição.",
"An error occurred!" => "Ocorreu um erro!",
"Text file" => "Arquivo texto",
"New text file.txt" => "Novo texto file.txt"
);
$PLURAL_FORMS = "nplurals=2; plural=(n > 1);";
